==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Surface_mesh_approximation/group__PkgTSMARef.js <==
var group__PkgTSMARef =
[
    [ "Concepts", "group__PkgTSMAConcepts.html", "group__PkgTSMAConcepts" ],
    [ "L21_metric_plane_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html", [
      [ "Proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#a38fc08ebd9553b61fbbf75977492ffe8", null ],
      [ "L21_metric_plane_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#a64114275d4b2affb3035f77b0fb3578b", null ],
      [ "compute_error", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#acaf1643f77fc43ff8b25c4f5c40a613c", null ],
      [ "fit_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#aa16d83baf123788d4a58b9845401ac0a", null ]
    ] ],
    [ "L2_metric_plane_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html", [
      [ "Proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#a52728f411095922fff1023e31b3361f7", null ],
      [ "L2_metric_plane_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#a93ae770bef9b421ca6a23230fe339d73", null ],
      [ "compute_error", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#a03e731128342073ab6f3566945cb8fad", null ],
      [ "fit_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#aa5cd877a51a864f4a376ac7215bbf8fc", null ]
    ] ],
    [ "Variational_shape_approximation", "classCGAL_1_1Variational__shape__approximation.html", [
      [ "Error_metric", "classCGAL_1_1Variational__shape__approximation.html#a677e39022d7329ab7d6f814d9268c219", null ],
      [ "Geom_traits", "classCGAL_1_1Variational__shape__approximation.html#ad5ade55941496a0ebddd9f596fc324ed", null ],
      [ "Indexed_triangle", "classCGAL_1_1Variational__shape__approximation.html#a9ae374c6f317af38d1c5ccfc1143c9be", null ],
      [ "Proxy", "classCGAL_1_1Variational__shape__approximation.html#a063a3c637d747c59321dd254c2f0a77f", null ],
      [ "Variational_shape_approximation", "classCGAL_1_1Variational__shape__approximation.html#a46d33e5e7cc6bf38e7c45f62161ac571", null ],
      [ "add_proxies_error_diffusion", "classCGAL_1_1Variational__shape__approximation.html#a0ce424a199eab4d77ef5f145f98721d7", null ],
      [ "add_to_furthest_proxies", "classCGAL_1_1Variational__shape__approximation.html#a4b75f99cc39f49ecdb6f01da43b7926a", null ],
      [ "compute_total_error", "classCGAL_1_1Variational__shape__approximation.html#ac63a0aabddf9e069d60e833d4626132b", null ],
      [ "extract_mesh", "classCGAL_1_1Variational__shape__approximation.html#a94c248ead7a448407ee5ef0a0865a969", null ],
      [ "find_best_merge", "classCGAL_1_1Variational__shape__approximation.html#a2e3dfc29b1fc745f2c264deed84f70aa", null ],
      [ "initialize_seeds", "classCGAL_1_1Variational__shape__approximation.html#a8b5b69c3f841a27f7a5c9ebde1ecc8bb", null ],
      [ "merge", "classCGAL_1_1Variational__shape__approximation.html#a22339caadc88fd295c016a5dc11337f2", null ],
      [ "number_of_proxies", "classCGAL_1_1Variational__shape__approximation.html#ab27b2180e2a455becc821ec5d2cb1289", null ],
      [ "output", "classCGAL_1_1Variational__shape__approximation.html#a057ed7685d6b18427956ab101a76c486", null ],
      [ "run", "classCGAL_1_1Variational__shape__approximation.html#a9fa9ea011fc167ebc5aa301452af60cf", null ],
      [ "run_to_convergence", "classCGAL_1_1Variational__shape__approximation.html#a849559eef2cc667c55ce624307008eed", null ],
      [ "split", "classCGAL_1_1Variational__shape__approximation.html#a00421a33b857837ff9b5e79d7f3041bd", null ],
      [ "teleport_proxies", "classCGAL_1_1Variational__shape__approximation.html#a3024a46e321508ca5b92b66ef74d5876", null ]
    ] ],
    [ "Seeding_method", "group__PkgTSMARef.html#ga7455c45cae40d0da3f590267cc92f23e", [
      [ "RANDOM", "group__PkgTSMARef.html#gga7455c45cae40d0da3f590267cc92f23ea00552e1c6a6e16fc41135c53fb8d5ff9", null ],
      [ "INCREMENTAL", "group__PkgTSMARef.html#gga7455c45cae40d0da3f590267cc92f23ea26318c48b8ee65751d644e552e12412f", null ],
      [ "HIERARCHICAL", "group__PkgTSMARef.html#gga7455c45cae40d0da3f590267cc92f23eaffbab2672269c2302e67726a725ae396", null ]
    ] ],
    [ "Verbose_level", "group__PkgTSMARef.html#gaf2c6637c1a37e64d0a50ec9981f1e0a1", [
      [ "SILENT", "group__PkgTSMARef.html#ggaf2c6637c1a37e64d0a50ec9981f1e0a1a7daee775a5374e7ebe7e0a890f339d07", null ],
      [ "MAIN_STEPS", "group__PkgTSMARef.html#ggaf2c6637c1a37e64d0a50ec9981f1e0a1aebfaff0d43e06852ca2b6a1a2b8e9603", null ],
      [ "VERBOSE", "group__PkgTSMARef.html#ggaf2c6637c1a37e64d0a50ec9981f1e0a1a702fbb1a63b533e4f3afdbca53f16e86", null ]
    ] ],
    [ "approximate_triangle_mesh", "group__PkgTSMARef.html#ga4bd463b1bad91654f253895861d37dbd", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Surface_mesh_approximation/group__PkgTSMARef.js <==
var group__PkgTSMARef =
[
    [ "Concepts", "group__PkgTSMAConcepts.html", "group__PkgTSMAConcepts" ],
    [ "CGAL::Surface_mesh_approximation::L21_metric_plane_proxy< TriangleMesh, VertexPointMap, GeomTraits >", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html", [
      [ "Proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#a38fc08ebd9553b61fbbf75977492ffe8", null ],
      [ "L21_metric_plane_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#a64114275d4b2affb3035f77b0fb3578b", null ],
      [ "compute_error", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#acaf1643f77fc43ff8b25c4f5c40a613c", null ],
      [ "fit_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L21__metric__plane__proxy.html#aa16d83baf123788d4a58b9845401ac0a", null ]
    ] ],
    [ "CGAL::Surface_mesh_approximation::L2_metric_plane_proxy< TriangleMesh, VertexPointMap, GeomTraits >", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html", [
      [ "Proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#a52728f411095922fff1023e31b3361f7", null ],
      [ "L2_metric_plane_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#a93ae770bef9b421ca6a23230fe339d73", null ],
      [ "compute_error", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#a03e731128342073ab6f3566945cb8fad", null ],
      [ "fit_proxy", "classCGAL_1_1Surface__mesh__approximation_1_1L2__metric__plane__proxy.html#aa5cd877a51a864f4a376ac7215bbf8fc", null ]
    ] ],
    [ "CGAL::Variational_shape_approximation< TriangleMesh, VertexPointMap, ErrorMetricProxy, GeomTraits, Concurrency_tag >", "classCGAL_1_1Variational__shape__approximation.html", [
      [ "Error_metric", "classCGAL_1_1Variational__shape__approximation.html#a677e39022d7329ab7d6f814d9268c219", null ],
      [ "Geom_traits", "classCGAL_1_1Variational__shape__approximation.html#ad5ade55941496a0ebddd9f596fc324ed", null ],
      [ "Indexed_triangle", "classCGAL_1_1Variational__shape__approximation.html#a9ae374c6f317af38d1c5ccfc1143c9be", null ],
      [ "Proxy", "classCGAL_1_1Variational__shape__approximation.html#a063a3c637d747c59321dd254c2f0a77f", null ],
      [ "Variational_shape_approximation", "classCGAL_1_1Variational__shape__approximation.html#a46d33e5e7cc6bf38e7c45f62161ac571", null ],
      [ "add_proxies_error_diffusion", "classCGAL_1_1Variational__shape__approximation.html#a0ce424a199eab4d77ef5f145f98721d7", null ],
      [ "add_to_furthest_proxies", "classCGAL_1_1Variational__shape__approximation.html#a4b75f99cc39f49ecdb6f01da43b7926a", null ],
      [ "compute_total_error", "classCGAL_1_1Variational__shape__approximation.html#ac63a0aabddf9e069d60e833d4626132b", null ],
      [ "extract_mesh", "classCGAL_1_1Variational__shape__approximation.html#a94c248ead7a448407ee5ef0a0865a969", null ],
      [ "find_best_merge", "classCGAL_1_1Variational__shape__approximation.html#a25138713b1f02ac1cd89012f5bad0fb6", null ],
      [ "initialize_seeds", "classCGAL_1_1Variational__shape__approximation.html#a8b5b69c3f841a27f7a5c9ebde1ecc8bb", null ],
      [ "merge", "classCGAL_1_1Variational__shape__approximation.html#a22339caadc88fd295c016a5dc11337f2", null ],
      [ "number_of_proxies", "classCGAL_1_1Variational__shape__approximation.html#ab27b2180e2a455becc821ec5d2cb1289", null ],
      [ "output", "classCGAL_1_1Variational__shape__approximation.html#a057ed7685d6b18427956ab101a76c486", null ],
      [ "run", "classCGAL_1_1Variational__shape__approximation.html#a9fa9ea011fc167ebc5aa301452af60cf", null ],
      [ "run_to_convergence", "classCGAL_1_1Variational__shape__approximation.html#a849559eef2cc667c55ce624307008eed", null ],
      [ "split", "classCGAL_1_1Variational__shape__approximation.html#a00421a33b857837ff9b5e79d7f3041bd", null ],
      [ "teleport_proxies", "classCGAL_1_1Variational__shape__approximation.html#a3024a46e321508ca5b92b66ef74d5876", null ]
    ] ],
    [ "CGAL::Surface_mesh_approximation::Seeding_method", "group__PkgTSMARef.html#ga7455c45cae40d0da3f590267cc92f23e", [
      [ "CGAL::Surface_mesh_approximation::RANDOM", "group__PkgTSMARef.html#gga7455c45cae40d0da3f590267cc92f23ea00552e1c6a6e16fc41135c53fb8d5ff9", null ],
      [ "CGAL::Surface_mesh_approximation::INCREMENTAL", "group__PkgTSMARef.html#gga7455c45cae40d0da3f590267cc92f23ea26318c48b8ee65751d644e552e12412f", null ],
      [ "CGAL::Surface_mesh_approximation::HIERARCHICAL", "group__PkgTSMARef.html#gga7455c45cae40d0da3f590267cc92f23eaffbab2672269c2302e67726a725ae396", null ]
    ] ],
    [ "CGAL::Surface_mesh_approximation::Verbose_level", "group__PkgTSMARef.html#gaf2c6637c1a37e64d0a50ec9981f1e0a1", [
      [ "CGAL::Surface_mesh_approximation::SILENT", "group__PkgTSMARef.html#ggaf2c6637c1a37e64d0a50ec9981f1e0a1a7daee775a5374e7ebe7e0a890f339d07", null ],
      [ "CGAL::Surface_mesh_approximation::MAIN_STEPS", "group__PkgTSMARef.html#ggaf2c6637c1a37e64d0a50ec9981f1e0a1aebfaff0d43e06852ca2b6a1a2b8e9603", null ],
      [ "CGAL::Surface_mesh_approximation::VERBOSE", "group__PkgTSMARef.html#ggaf2c6637c1a37e64d0a50ec9981f1e0a1a702fbb1a63b533e4f3afdbca53f16e86", null ]
    ] ],
    [ "CGAL::Surface_mesh_approximation::approximate_triangle_mesh", "group__PkgTSMARef.html#ga4bd463b1bad91654f253895861d37dbd", null ]
];
